==> dtkdeclarative-debug-5.6.24-1-x86_64.pkg.tar.zst: usr/src/debug/dtkdeclarative/dtkdeclarative-5.6.24/src/qml_HelpAction_qml.cpp <==
// /dtk/declarative/qml/HelpAction.qml
namespace QmlCacheGeneratedCode {
namespace _dtk_declarative_qml_HelpAction_qml {
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x29,0x0,0x0,0x0,0xc,0xf,0x5,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd4,0x4,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb1,0x33,0x1a,0xe5,
0xd0,0x60,0xd9,0x5a,0x9f,0xe4,0x1e,0x8f,
0x5c,0xc4,0x49,0x14,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x88,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x8,0x4,0x0,0x0,
0x20,0x1,0x0,0x0,0x78,0x1,0x0,0x0,
0x23,0x0,0x0,0x0,0xa0,0x0,0x0,0x0,
0xb0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x40,0x0,0x0,0x0,0x12,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0xb,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0xc6,0x2e,0x0,0x3a,0x1,0x18,0x7,0xa6,
0x2,0x7,0x0,0x0,0x18,0x6,0xd0,0x16,
0x6,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb8,0x1,0x0,0x0,0xd8,0x1,0x0,0x0,
0x0,0x2,0x0,0x0,0x20,0x2,0x0,0x0,
0x60,0x2,0x0,0x0,0x88,0x2,0x0,0x0,
0xb8,0x2,0x0,0x0,0xe0,0x2,0x0,0x0,
0x8,0x3,0x0,0x0,0x38,0x3,0x0,0x0,
0x88,0x3,0x0,0x0,0xc8,0x3,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x51,0x0,0x74,0x0,0x51,0x0,0x75,0x0,
0x69,0x0,0x63,0x0,0x6b,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x13,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6f,0x0,0x72,0x0,0x67,0x0,0x2e,0x0,
0x64,0x0,0x65,0x0,0x65,0x0,0x70,0x0,
0x69,0x0,0x6e,0x0,0x2e,0x0,0x64,0x0,
0x74,0x0,0x6b,0x0,0x2e,0x0,0x69,0x0,
0x6d,0x0,0x70,0x0,0x6c,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x6,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x41,0x0,0x63,0x0,0x74,0x0,0x69,0x0,
0x6f,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x68,0x0,0x65,0x0,0x6c,0x0,0x70,0x0,
0x41,0x0,0x63,0x0,0x74,0x0,0x69,0x0,
0x6f,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x74,0x0,0x65,0x0,0x78,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x48,0x0,0x65,0x0,0x6c,0x0,0x70,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0xb,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6f,0x0,0x6e,0x0,0x54,0x0,0x72,0x0,
0x69,0x0,0x67,0x0,0x67,0x0,0x65,0x0,
0x72,0x0,0x65,0x0,0x64,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x1a,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x65,0x0,0x78,0x0,0x70,0x0,0x72,0x0,
0x65,0x0,0x73,0x0,0x73,0x0,0x69,0x0,
0x6f,0x0,0x6e,0x0,0x20,0x0,0x66,0x0,
0x6f,0x0,0x72,0x0,0x20,0x0,0x6f,0x0,
0x6e,0x0,0x54,0x0,0x72,0x0,0x69,0x0,
0x67,0x0,0x67,0x0,0x65,0x0,0x72,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x11,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x41,0x0,0x70,0x0,0x70,0x0,0x6c,0x0,
0x69,0x0,0x63,0x0,0x61,0x0,0x74,0x0,
0x69,0x0,0x6f,0x0,0x6e,0x0,0x48,0x0,
0x65,0x0,0x6c,0x0,0x70,0x0,0x65,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x68,0x0,0x61,0x0,0x6e,0x0,0x64,0x0,
0x6c,0x0,0x65,0x0,0x48,0x0,0x65,0x0,
0x6c,0x0,0x70,0x0,0x41,0x0,0x63,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x40,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x5,0x0,0x10,0x0,
0x1,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6,0x0,0x10,0x0,
0x44,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x2,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x84,0x0,0x0,0x0,
0x8,0x0,0x10,0x0,0x9,0x0,0x50,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x50,0x0,0xb,0x0,0x30,0x1,
0x6,0x0,0x0,0x0,0x0,0x0,0x5,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x50,0x0,0xa,0x0,0xb0,0x0,
0x0,0x0,0x0,0x0
};
}
}

==> dtkdeclarative-debug-5.6.26-1-x86_64.pkg.tar.zst: usr/src/debug/dtkdeclarative/dtkdeclarative-5.6.26/src/qml_HelpAction_qml.cpp <==
// /dtk/declarative/qml/HelpAction.qml
namespace QmlCacheGeneratedCode {
namespace _dtk_declarative_qml_HelpAction_qml {
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x29,0x0,0x0,0x0,0xd,0xf,0x5,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd4,0x4,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb1,0x33,0x1a,0xe5,
0xd0,0x60,0xd9,0x5a,0x9f,0xe4,0x1e,0x8f,
0x5c,0xc4,0x49,0x14,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x88,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x8,0x4,0x0,0x0,
0x20,0x1,0x0,0x0,0x78,0x1,0x0,0x0,
0x23,0x0,0x0,0x0,0xa0,0x0,0x0,0x0,
0xb0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x40,0x0,0x0,0x0,0x12,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0xb,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0xc6,0x2e,0x0,0x3a,0x1,0x18,0x7,0xa6,
0x2,0x7,0x0,0x0,0x18,0x6,0xd0,0x16,
0x6,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb8,0x1,0x0,0x0,0xd8,0x1,0x0,0x0,
0x0,0x2,0x0,0x0,0x20,0x2,0x0,0x0,
0x60,0x2,0x0,0x0,0x88,0x2,0x0,0x0,
0xb8,0x2,0x0,0x0,0xe0,0x2,0x0,0x0,
0x8,0x3,0x0,0x0,0x38,0x3,0x0,0x0,
0x88,0x3,0x0,0x0,0xc8,0x3,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x51,0x0,0x74,0x0,0x51,0x0,0x75,0x0,
0x69,0x0,0x63,0x0,0x6b,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x13,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6f,0x0,0x72,0x0,0x67,0x0,0x2e,0x0,
0x64,0x0,0x65,0x0,0x65,0x0,0x70,0x0,
0x69,0x0,0x6e,0x0,0x2e,0x0,0x64,0x0,
0x74,0x0,0x6b,0x0,0x2e,0x0,0x69,0x0,
0x6d,0x0,0x70,0x0,0x6c,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x6,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x41,0x0,0x63,0x0,0x74,0x0,0x69,0x0,
0x6f,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x68,0x0,0x65,0x0,0x6c,0x0,0x70,0x0,
0x41,0x0,0x63,0x0,0x74,0x0,0x69,0x0,
0x6f,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x74,0x0,0x65,0x0,0x78,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x48,0x0,0x65,0x0,0x6c,0x0,0x70,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0xb,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6f,0x0,0x6e,0x0,0x54,0x0,0x72,0x0,
0x69,0x0,0x67,0x0,0x67,0x0,0x65,0x0,
0x72,0x0,0x65,0x0,0x64,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x1a,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x65,0x0,0x78,0x0,0x70,0x0,0x72,0x0,
0x65,0x0,0x73,0x0,0x73,0x0,0x69,0x0,
0x6f,0x0,0x6e,0x0,0x20,0x0,0x66,0x0,
0x6f,0x0,0x72,0x0,0x20,0x0,0x6f,0x0,
0x6e,0x0,0x54,0x0,0x72,0x0,0x69,0x0,
0x67,0x0,0x67,0x0,0x65,0x0,0x72,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x11,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x41,0x0,0x70,0x0,0x70,0x0,0x6c,0x0,
0x69,0x0,0x63,0x0,0x61,0x0,0x74,0x0,
0x69,0x0,0x6f,0x0,0x6e,0x0,0x48,0x0,
0x65,0x0,0x6c,0x0,0x70,0x0,0x65,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x68,0x0,0x61,0x0,0x6e,0x0,0x64,0x0,
0x6c,0x0,0x65,0x0,0x48,0x0,0x65,0x0,
0x6c,0x0,0x70,0x0,0x41,0x0,0x63,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x40,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x5,0x0,0x10,0x0,
0x1,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6,0x0,0x10,0x0,
0x44,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x2,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x84,0x0,0x0,0x0,
0x8,0x0,0x10,0x0,0x9,0x0,0x50,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x50,0x0,0xb,0x0,0x30,0x1,
0x6,0x0,0x0,0x0,0x0,0x0,0x5,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x50,0x0,0xa,0x0,0xb0,0x0,
0x0,0x0,0x0,0x0
};
}
}
